simplify.BadRequestError.FieldError

Package simplify :: Class BadRequestError :: Class FieldError |
[hide private]
[frames] | no frames]

# Class FieldError

source code

Represents a single error in a field of data sent in a request to the API.

Instance Methods | [hide private]
__init__(self, error_data) | source code
__str__(self) | source code

Instance Variables | [hide private]
| error_code a string code for the error.
| field_name the name of the field with the error.
| message a string description of the error.